=====
model
=====


.. automodule:: camelot.model
   :members:

.. toctree::

   authentication.rst
   batch_job.rst
   fixture.rst
   i18n.rst
   memento.rst
   synchronization.rst
   task.rst
   type_and_status.rst
